# Generated by Django 4.0.6 on 2022-07-12 09:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('SMS', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='SmsToken',
        ),
    ]
